HitGrid

Struct HitGrid 

pub struct HitGrid { /* private fields */ }
Hit testing grid for mouse interaction.

Maps screen positions to widget IDs, enabling widgets to receive mouse events for their regions.

Implementations

Source

impl HitGrid

pub fn new(width: u16, height: u16) -> Self

Create a new hit grid with the given dimensions.

pub const fn width(&self) -> u16

Grid width.

pub const fn height(&self) -> u16

Grid height.

pub fn get(&self, x: u16, y: u16) -> Option<&HitCell>

Get the hit cell at (x, y).

pub fn get_mut(&mut self, x: u16, y: u16) -> Option<&mut HitCell>

Get mutable reference to hit cell at (x, y).

pub fn register( &mut self, rect: Rect, widget_id: HitId, region: HitRegion, data: HitData, )

Register a clickable region with the given hit metadata.

All cells within the rectangle will map to this hit cell.

pub fn hit_test(&self, x: u16, y: u16) -> Option<(HitId, HitRegion, HitData)>

Hit test at the given position.

Returns the hit tuple if a region is registered at (x, y).

pub fn hits_in(&self, rect: Rect) -> Vec<(HitId, HitRegion, HitData)>

Return all hits within the given rectangle.

pub fn clear(&mut self)

Clear all hit regions.