pub struct GuardrailVerdict {
pub alerts: Vec<GuardrailAlert>,
pub queue_action: QueueAction,
pub recommended_level: DegradationLevel,
}Expand description
Verdict from a guardrail check, combining all subsystem results.
Fields
alerts: Vec<GuardrailAlert>Alerts from all guardrails that fired (may be empty).
queue_action: QueueActionQueue action recommended by queue guardrails.
recommended_level: DegradationLevelThe most aggressive degradation level recommended across all alerts.
Implementations
Sourceimpl GuardrailVerdict
impl GuardrailVerdict
Sourcepub fn should_drop_frame(&self) -> bool
pub fn should_drop_frame(&self) -> bool
Whether any guardrail recommends dropping the current frame.
Sourcepub fn should_degrade(&self) -> bool
pub fn should_degrade(&self) -> bool
Whether any guardrail recommends degradation (but not frame skip).
Sourcepub fn max_severity(&self) -> Option<AlertSeverity>
pub fn max_severity(&self) -> Option<AlertSeverity>
The highest severity among all alerts, or None if clear.